@@ -91,7 +91,7 @@ resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
   res <- (is.integer(pid) || is.null(pid))
 
   ## Signal conditions early? (happens only iff requested)
-  if (res) signalEarly(x)
+  if (res) signalEarly(x, ...)
 
   res
 }
@@ -119,7 +119,7 @@ value.MulticoreFuture <- function(future, signal=TRUE, ...) {
   ## turn into an error with a more informative error message, cf.
   ## https://github.com/HenrikBengtsson/future/issues/35
   if (identical(res, structure("fatal error in wrapper code", class="try-error"))) {
-    stop(sprintf("Detected an error ('%s') by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evalutes the future was terminated before it was completed.", res, class(future)[1], sQuote(hexpr(future$expr))))
+    stop(FutureError(sprintf("Detected an error ('%s') by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evalutes the future was terminated before it was completed.", res, class(future)[1], sQuote(hexpr(future$expr))), future=future))
   }
 
   ## Update value and state
