@@ -14,7 +14,7 @@
 #' in time when the future is created (always before it is resolved),
 #' that is, they identified and located.  If some globals fail to be
 #' located, an informative error is generated.
-#' @param maxCores The maximum number of multiprocess futures that
+#' @param workers The maximum number of multiprocess futures that
 #' can be active at the same time before blocking.
 #' @param earlySignal Specified whether conditions should be signaled as soon as possible or not.
 #' @param \dots Not used.
@@ -29,9 +29,9 @@
 #' are used.
 #'
 #' @export
-multiprocess <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, maxCores=availableCores(), earlySignal=FALSE, ...) {
+multiprocess <- function(expr, envir=parent.frame(), substitute=TRUE, globals=TRUE, workers=availableCores(), earlySignal=FALSE, ...) {
   if (substitute) expr <- substitute(expr)
   fun <- if (supportsMulticore()) multicore else multisession
-  fun(expr=expr, envir=envir, substitute=FALSE, globals=globals, maxCores=maxCores, earlySignal=earlySignal, ...)
+  fun(expr=expr, envir=envir, substitute=FALSE, globals=globals, workers=workers, earlySignal=earlySignal, ...)
 }
 class(multiprocess) <- c("multiprocess", "future", "function")
