@@ -3,10 +3,12 @@
 futurize.py
 ===========
 
-Like Armin Ronacher's ``modernize.py``, but using the ``future`` package rather than a direct dependency on ``six``'.
+This script is only used by the unit tests. Another script called
+"futurize" is created automatically (without the .py extension) by
+setuptools.
 
-futurize.py attempts to turn Py2 code into valid, clean Py3 code that is also
-compatible with Py2 when using the ``future`` package.
+futurize.py attempts to turn Py2 code into valid, clean Py3 code that is
+also compatible with Py2 when using the ``future`` package.
 
 
 Licensing
